@@ -264,9 +264,67 @@ Take a look to the examples directory.
 
 =head2 Server example
 
+    use strict;
+    use warnings;
+    use IO::Socket::SIPC;
+
+    my $sipc = IO::Socket::SIPC->new(
+       favorite      => 'IO::Socket::INET',
+       use_check_sum => 1,
+    );
+
+    $sipc->connect(
+       LocalAddr  => 'localhost',
+       LocalPort  => 50010,
+       Proto      => 'tcp',
+       Listen     => 10, 
+       Reuse      => 1,
+    ) or die $sipc->errstr;
+
+    $sipc->debug(1);
+
+    while ( 1 ) { 
+       my $client;
+       while ( $client = $sipc->accept(10) ) { 
+          print "connect from client: ", $client->sock->peerhost, "\n";
+          my $request = $client->read_raw or die $client->errstr;
+          next unless $request;
+          chomp($request);
+          warn "client says: $request\n";
+          $client->send({ foo => 'is foo', bar => 'is bar', baz => 'is baz'}) or die $client->errstr;
+          $client->disconnect or die $client->errstr;
+       }   
+       die $sipc->errstr unless defined $client;
+       warn "server runs on a timeout, re-listen on socket\n";
+    }
+
+    $sipc->disconnect or die $sipc->errstr;
 
 =head2 Client example
 
+    use strict;
+    use warnings;
+    use Data::Dumper;
+    use IO::Socket::SIPC;
+
+    my $sipc = IO::Socket::SIPC->new(
+       favorite      => 'IO::Socket::INET',
+       use_check_sum => 1,
+    );
+
+    $sipc->connect(
+       PeerAddr => 'localhost',
+       PeerPort => 50010,
+       Proto    => 'tcp',
+    ) or die $sipc->errstr;
+
+    $sipc->debug(1);
+
+    $sipc->send_raw("Hello server, gimme some data :-)\n") or die $sipc->errstr;
+    my $answer = $sipc->read or die $sipc->errstr;
+    warn "server data: \n";
+    warn Dumper($answer);
+    $sipc->disconnect or die $sipc->errstr;
 
 =head1 PREREQUISITES
 
@@ -313,7 +371,7 @@ modify it under the same terms as Perl itself.
 =cut
 
 package IO::Socket::SIPC;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use strict;
 use warnings;
